<?php

namespace App\Filament\Resources\DeploymentOpportunityResource\RelationManagers;

use App\Mail\ApplicationApprovedMail;
use App\Models\DeploymentApplication;
use App\Models\User;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Notifications\Actions\Action;
use Filament\Notifications\Notification;
use Filament\Resources\RelationManagers\RelationManager;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Support\Facades\Mail;


class DeploymentApplicationRelationManager extends RelationManager
{
    protected static string $relationship = 'deployment_application';

    public function form(Form $form): Form
    {
        return $form
            ->schema([
                
                Forms\Components\Select::make('status')
                    ->options([
                        'Pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                ])
                ->hidden(! auth()->user()->hasAnyRole('Admin'))
                ->default('pending')
                ->saveRelationshipsWhenHidden()
                ->label(__('deploymentApplication.status')),
                
            ]);
    }

    public function table(Table $table): Table
    {
       
          return $table
            ->recordTitleAttribute('id')
            ->columns([
                Tables\Columns\TextColumn::make('id'),
                Tables\Columns\TextColumn::make('user_data.name')
                    ->numeric()
                    ->sortable()
                    ->searchable()
                    ->label('Applicant Name'),
                Tables\Columns\TextColumn::make('status')
                    ->badge()
                    ->colors([
                        'warning' => 'pending',
                        'success' => 'Approved',
                        'danger' => 'Denied'
                    ])
                    ->searchable(),
                   //READINESS RRT

                    Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_1.name')
                ->label(__('readinessAndRtMember.training_1'))
                    ->sortable(),
                 Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_1_date')
                 ->label(__('readinessAndRtMember.training_1_start_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_1_expiration_date')
                ->label(__('readinessAndRtMember.training_1_expiration_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_2.name')
                ->label(__('readinessAndRtMember.training_2'))
                    ->sortable(),
                      Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_2_date')
                      ->label(__('readinessAndRtMember.training_2_start_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_2_expiration_date')
                ->label(__('readinessAndRtMember.training_2_expiration_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.trainings_3.name')
                ->label(__('readinessAndRtMember.trainings_3'))
                    ->sortable()->sortable()->searchable(),
               Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_3_date')
               ->label(__('readinessAndRtMember.training_3_start_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_3_expiration_date')
                ->label(__('readinessAndRtMember.training_3_expiration_date'))
                    ->date()
                    ->sortable()->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                     Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_4.name')
                     ->label(__('readinessAndRtMember.training_4'))
                    ->sortable()->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_4_date')
                ->label(__('readinessAndRtMember.training_4_start_date'))
                    ->date()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.readiness_and_rt_member.training_4_expiration_date')
                ->label(__('readinessAndRtMember.training_4_expiration_date'))
                    ->date()
                    
                    ->sortable()
                     ->toggleable(isToggledHiddenByDefault: true),
                

//CASE MANAGEMENTS

                Tables\Columns\TextColumn::make('user_data.case_management.rapid_risk_assessments.name')
                    ->label(__('caseManagement.rapid_risk_assessments'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.case_management.clinical_management_advice_and_recommendations.name')
                    ->label(__('caseManagement.clinical_management_advice_and_recommendations'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.case_management.icp_in_the_care_facility.name')
                    ->label(__('caseManagement.icp_in_the_care_facility'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.case_management.monitoring_system.name')
                    ->label(__('caseManagement.monitoring_system'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.case_management.determination_of_disease_status.name')
                    ->label(__('caseManagement.determination_of_disease_status'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                    
                    
///CREC
                    Tables\Columns\TextColumn::make('user_data.crec.experience_in_health.name')
                    ->label(__('crecs.experience_in_health'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.crec.media_environments.name')
                    ->label(__('crecs.media_environments'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.crec.media_comms_content.name')
                    ->label(__('crecs.media_comms_content'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.crec.graphic_design.name')
                    ->label(__('crecs.graphic_design'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.crec.social_media_web_contnet.name')
                    ->label(__('crecs.social_media_web_contnet'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.crec.comms_field_deployment.name')
                    ->label(__('crecs.comms_field_deployment'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.adience_analysis_strategies.name')
                    ->label(__('crecs.adience_analysis_strategies'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.community_engagement.name')
                    ->label(__('crecs.community_engagement'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.health_education_comms_prog.name')
                    ->label(__('crecs.health_education_comms_prog'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.intervener_content_hearing.name')
                    ->label(__('crecs.intervener_content_hearing'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.stakeholder_organisation.name')
                    ->label(__('crecs.stakeholder_organisation'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.response_risk_responsibility.name')
                    ->label(__('crecs.response_risk_responsibility'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.decision_memos.name')
                    ->label(__('crecs.decision_memos'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.Strategic_communications_planning.name')
                    ->label(__('crecs.Strategic_communications_planning'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.CHES_MCHES.name')
                    ->label(__('crecs.CHES_MCHES'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.CERC_participation.name')
                    ->label(__('crecs.CERC_participation'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.CERC_Trainer.name')
                    ->label(__('crecs.CERC_Trainer'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('user_data.crec.political_Experience.name')
                    ->label(__('crecs.political_Experience'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable()->searchable(),
                    

//DATA MANAGEMENT 
                    Tables\Columns\TextColumn::make('user_data.data.management.quantitative_data.name')
                        ->label(__('dataManagement.id'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.excel.name')
                    ->label(__('dataManagement.excel'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.access.name')
                    ->label(__('dataManagement.access'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.sas.name')
                    ->label(__('dataManagement.sas'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.spss.name')
                    ->label(__('dataManagement.spss'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.status.name')
                    ->label(__('dataManagement.status'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.r.name')
                    ->label(__('dataManagement.r'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.epi_info.name')
                    ->label(__('dataManagement.epi_info'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.monitoring_database.name')
                    ->label(__('dataManagement.monitoring_database'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.qualitative_data.name')
                    ->label(__('dataManagement.qualitative_data'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.data_visualization.name')
                    ->label(__('dataManagement.data_visualization'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.data.management.geographic_information_system_gis.name')
                    ->label(__('dataManagement.geographic_information_system_gis'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),


//REGISTRATION DATA
                Tables\Columns\TextColumn::make('user_data.register.agency_structure.name')
                ->label(__('register.structure_of_agency'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('user_data.register.department.name')
                ->label(__('register.department'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('user_data.register.profession.name')
                ->label(__('register.profession'))
                    ->searchable(),
                    //->hiddenFrom('md'),
                Tables\Columns\TextColumn::make('user_data.register.name_of_supervisory_line_manager')
                ->label(__('register.name_of_supervisory_line_manager'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.supervisorr_email')
                ->label(__('register.supervisorr_email'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.fetp_mmber')
                ->label(__('register.fetp_mmber'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.fetp_graduate')
                ->label(__('register.fetp_graduate'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.city_of_residence')
                ->label(__('register.city_of_residence')),
                Tables\Columns\TextColumn::make('user_data.register.phone_number')
                ->label(__('register.phone_number'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.email_address')
                ->label(__('register.phone_number'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.national_agency_employee')
                ->label(__('register.email_address'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.public_health_experience_drc')
                ->label(__('register.national_agency_employee'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.if_yes_number')
                ->label(__('register.public_health_experience_drc'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.eoc_experience')
                ->label(__('register.if_yes_number'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.eoc_if_yes_number_of_years')
                ->label(__('register.eoc_experience'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.international_work_experience_no_study_abroad')
                ->label(__('register.eoc_if_yes_number_of_years'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.number_international_deployments')
                ->label(__('register.international_work_experience_no_study_abroad'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.experience_as_a_team_leader')
                ->label(__('register.number_international_deployments'))
                    ->searchable() ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.register.if_yes_above_number_of_deployments_as_tl')
                ->label(__('register.experience_as_a_team_leader'))
                    ->numeric()
                    ->sortable() ->toggleable(isToggledHiddenByDefault: true),

//EMERGENCY LOGISTICS

                     Tables\Columns\TextColumn::make('user_data.emergency_logistic.shipping_and_receiving.name')
                    ->label(__('emergencyLogistic.shipping_and_receiving'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.sample_packaging.name')
                    ->label(__('emergencyLogistic.sample_packaging'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.inventory_management.name')
                    ->label(__('emergencyLogistic.inventory_management'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.travel_coordinator.name')
                    ->label(__('emergencyLogistic.travel_coordinator'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.fleet_management.name')
                    ->label(__('emergencyLogistic.fleet_management'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.moving_resources_to_the_field.name')
                    ->label(__('emergencyLogistic.moving_resources_to_the_field'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.deployer_training_resources.name')
                    ->label(__('emergencyLogistic.deployer_training_resources'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.emergency_logistic.eoc_logistics_emergency_operations_center.name')
                    ->label(__('emergencyLogistic.eoc_logistics_emergency_operations_center'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),

//EMERGENCY RESPONSE


                     Tables\Columns\TextColumn::make('user_data.emergency_response.domestic_emergency_response.name')
                    ->label(__('emergencyResponse.domestic_emergency_response'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.cross_sectoral.name')
                    ->label(__('emergencyResponse.cross_sectoral'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.response_to_international_emergencies.name')
                    ->label(__('emergencyResponse.response_to_international_emergencies'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.eoc_ims.name')
                    ->label(__('emergencyResponse.eoc_ims'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.vaccination_campaigns.name')
                    ->label(__('emergencyResponse.vaccination_campaigns'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.emergency_leadership_role.name')
                    ->label(__('emergencyResponse.emergency_leadership_role'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.multi_sectoral_emergency_response_plans.name')
                    ->label(__('emergencyResponse.multi_sectoral_emergency_response_plans'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.emergency_response.emergency_diseases.name')
                    ->label(__('emergencyResponse.emergency_diseases'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),


//EXPERIENCE IN EPIDEMIOOLGY


                    Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.rapid_risk_assessments.name')
                    ->label(__('experienceInEpidemiology.rapid_risk_assessments'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.monitoring_system.name')
                    ->label(__('experienceInEpidemiology.monitoring_and_evaluation'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.epidemic_survey.name')
                    ->label(__('caseManagement.epidemic_survey'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.determination_of_disease_status.name')
                    ->label(__('experienceInEpidemiology.disease_surveillance'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.contact_tracing.name')
                    ->label(__('experienceInEpidemiology.contact_tracing'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.case_management.name')
                    ->label(__('experienceInEpidemiology.case_management'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.epidemiological_studies.name')
                    ->label(__('experienceInEpidemiology.epidemiological_studies'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.experience_in_epidemiology.study_protocols.name')
                    ->label(__('experienceInEpidemiology.study_protocols'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),


/// HAZARDOUS MATERIALS
                    

                    Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.certified_hazardous_materials_manager_chmm.name')
                    ->label(__('hazardousMaterialsExperience.certified_hazardous_materials_manager_chmm'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.certified_industrial_hygienist_cih.name')
                    ->label(__('hazardousMaterialsExperience.certified_industrial_hygienist_cih'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.hazmat_specialist_training.name')
                    ->label(__('hazardousMaterialsExperience.hazmat_specialist_training'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.record_keeping.name')
                    ->label(__('hazardousMaterialsExperience.record_keeping'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.hazardous_materials_management_y_n_program.name')
                    ->label(__('hazardousMaterialsExperience.hazardous_materials_management_y_n_program'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.medical_waste_plans.name')
                    ->label(__('hazardousMaterialsExperience.medical_waste_plans'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.spill_response_plans.name')
                    ->label(__('hazardousMaterialsExperience.spill_response_plans'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.hazardous_waste_reduction_plans.name')
                    ->label(__('hazardousMaterialsExperience.hazardous_waste_reduction_plans'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.hazardous_waste_contingency_plans.name')
                    ->label(__('hazardousMaterialsExperience.hazardous_waste_contingency_plans'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.stormwater_y_n_plans.name')
                    ->label(__('hazardousMaterialsExperience.stormwater_y_n_plans'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.occupational_health_and_safety_y_n_programs.name')
                    ->label(__('hazardousMaterialsExperience.occupational_health_and_safety_y_n_programs'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.radiation_protection_plan.name')
                    ->label(__('hazardousMaterialsExperience.radiation_protection_plan'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.collection_hazardous_waste.name')
                    ->label(__('hazardousMaterialsExperience.collection_hazardous_waste'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.hazardous_materials_experience.training_others_on_hazardous_waste.name')
                    ->label(__('hazardousMaterialsExperience.training_others_on_hazardous_waste'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),


/// INFECTION PREVENTION CONTROL

                 Tables\Columns\TextColumn::make('user_data.infection_prevention_control.in_healthcare_settings.name')
                    ->label(__('infectionPreventControl.in_healthcare_settings'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.in_a_non_medical.name')
                    ->label(__('infectionPreventControl.in_a_non_medical'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.outbreak_investigations.name')
                    ->label(__('infectionPreventControl.outbreak_investigations'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.facility_assessments.name')
                    ->label(__('infectionPreventControl.facility_assessments'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.developing_infection_prevention.name')
                    ->label(__('infectionPreventControl.developing_infection_prevention'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.infection_prevention_and_control.name')
                    ->label(__('infectionPreventControl.infection_prevention_and_control'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.quality_improvement.name')
                    ->label(__('infectionPreventControl.quality_improvement'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.ppe.name')
                    ->label(__('infectionPreventControl.ppe'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.point_of_entry_border_health.name')
                    ->label(__('infectionPreventControl.point_of_entry_border_health'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.poc_non_border.name')
                    ->label(__('infectionPreventControl.poc_non_border'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.infection_prevention_control.rsi.name')
                    ->label(__('infectionPreventControl.rsi'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),


/// LABORATORY EXPERIENCE

                Tables\Columns\TextColumn::make('user_data.laboratory_experience.biosafety_experience.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.biosafety_experience'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.laboratory_quality_management.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.laboratory_quality_management'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.sample_reception_and_acquisition.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.sample_reception_and_acquisition'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.sample_transport.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.sample_transport'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.antimicrobial.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.antimicrobial'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.parasitology.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.parasitology'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.mycology.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.mycology'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.clinical_chemistry.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.clinical_chemistry'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.blood_bank.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.blood_bank'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.molecular_methods.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.molecular_methods'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.advanced_molecular_detection_dma.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.advanced_molecular_detection_dma'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.viral_culture.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.viral_culture'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.serology.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.serology'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.bsl_3.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperienec.bsl_3'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.bacterial_culture.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.bacterial_culture'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.phlebotomy_venipuncture.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.phlebotomy_venipuncture'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.laboratory_training_instructor.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.laboratory_training_instructor'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.laboratory_supervisor_experience.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.laboratory_supervisor_experience'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.laboratory_experience.laboratory_field_intervention_coordinator.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('laboratoryExperience.laboratory_field_intervention_coordinator'))
                    ->numeric()
                    ->sortable(),


///NUTRITION EXPERIENCE

                    Tables\Columns\TextColumn::make('user_data.nutrition_experience.assessment_of_the_nutritional_status_of_the_population.name')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('nutritionExperience.assessment_of_the_nutritional_status_of_the_population'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('user_data.nutrition_experience.certified')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('nutritionExperience.certified'))
                    ->searchable(),


///PSYCOSOCIAL EXPERIENCE


                Tables\Columns\TextColumn::make('user_data.psycosocial_experience.licensee.name')
                    ->label(__('psychosocialExperience.licensee'))
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.psychiatrist.name')
                    ->label(__('psychosocialExperience.psychiatrist'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.advisor.name')
                    ->label(__('psychosocialExperience.advisor'))
                    ->numeric()
                    ->sortable()->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.social_worker.name')
                    ->label(__('psychosocialExperience.social_worker'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.trauma_based_therapy.name')
                    ->label(__('psychosocialExperience.trauma_based_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.cognitive_behavioural_therapy.name')
                    ->label(__('psychosocialExperience.cognitive_behavioural_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.psychodynamic_therapy.name')
                    ->label(__('psychosocialExperience.psychodynamic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.psychoanalytic_therapy.name')
                    ->label(__('psychosocialExperience.psychoanalytic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.integrative_or_holistic_therapy.name')
                    ->label(__('psychosocialExperience.integrative_or_holistic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.humanistic_therapy.name')
                    ->label(__('psychosocialExperience.humanistic_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),
                 Tables\Columns\TextColumn::make('user_data.psycosocial_experience.pediatric_therapy.name')
                    ->label(__('psychosocialExperience.pediatric_therapy'))
                    ->numeric()
                    ->sortable()->searchable()
                     ->toggleable(isToggledHiddenByDefault: true),

/// SECURITY MANAGEMENT EXPERIENCE

                    Tables\Columns\TextColumn::make('user_data.security_manager_experience.occupational_health_and_safety_assessment.name')
                    ->label(__('securityManager.occupational_health_and_safety_assessment'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.osh_y_n_facility_assessment.name')
                    ->label(__('securityManager.osh_y_n_facility_assessment'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.development_of_an_incident_action.name')
                    ->label(__('securityManager.development_of_an_incident_action'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.other_training_on_osh.name')
                    ->label(__('securityManager.other_training_on_osh'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.training_received_in_the_field_of_expertise.name')
                    ->label(__('securityManager.training_received_in_the_field_of_expertise'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.do_you_have_a_service_passport')
                    ->label(__('securityManager.do_you_have_a_service_passport'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.eir_volunteer')
                    ->label(__('securityManager.eir_volunteer'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.national_training_insert_name_and_date_of_just_in_time')
                    ->label(__('securityManager.national_training_insert_name_and_date_of_just_in_time'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.name_of_just_in_time_training')
                    ->label(__('securityManager.name_of_just_in_time_training'))
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.security_manager_experience.date_of_just_in_time_training')
                    ->label(__('securityManager.date_of_just_in_time_training'))
                    ->date()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),

///WATER AND SANITATION

                Tables\Columns\TextColumn::make('user_data.water_sanitation_hygiene_wash.in_healthcare_settings.name')
                    ->label(__('waterSanitation.in_healthcare_settings'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.water_sanitation_hygiene_wash.in_a_non_medical.name')
                    ->label(__('waterSanitation.in_a_non_medical'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.water_sanitation_hygiene_wash.source_water_assessment.name')
                    ->label(__('waterSanitation.source_water_assessment'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.water_sanitation_hygiene_wash.water_analysis.name')
                    ->label(__('waterSanitation.water_analysis'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.water_sanitation_hygiene_wash.train_others_on_water_testing_and_aquatab.name')
                    ->label(__('waterSanitation.train_others_on_water_testing_and_aquatab'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('user_data.water_sanitation_hygiene_wash.water_infrastructure_mapping.name')
                    ->label(__('waterSanitation.water_infrastructure_mapping'))
                    ->numeric()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                    
                   
                

            ])
            ->filters([
                //
            ])
            ->headerActions([
               //Tables\Actions\CreateAction::make(),
            ])
            ->actions([
                Tables\Actions\EditAction::make()
            
                ->after(function (DeploymentApplication $deploymentApplication) {
                    $user = User::where('id', $deploymentApplication->user_id)->get();
                    Notification::make()
                        ->success()
                        ->title( 'Your application for '.$deploymentApplication->deployment_opportunity->event_name.' has been approved')
                        ->icon('heroicon-o-document-text') 
                        ->iconColor('success') 
                        ->body('Congratulations, Your Application to '.$deploymentApplication->deployment_opportunity->event_name.' has been approved')
                        ->actions([
                            Action::make('markAsUnread')
                                ->button()
                                ->markAsUnread(),
                            Action::make('markAsRead')
                                ->button()
                                ->markAsRead(),
                        ])
                        ->sendToDatabase($user);
                    Mail::to($user[0]->email)->send(new ApplicationApprovedMail($deploymentApplication->deployment_opportunity->event_name,$deploymentApplication->deployment_opportunity->status, $user[0]->name ));                        

                    Notification::make()
                        ->success()
                        ->title(  $deploymentApplication->user->name . '\'s application for ' . $deploymentApplication->deployment_opportunity->event_name . ' set to ' . $deploymentApplication->status)
                        ->icon('heroicon-o-document-text') 
                        ->iconColor('success') 
                        ->body('You have set the application of '. $deploymentApplication->user->name . ' for ' . $deploymentApplication->deployment_opportunity->event_name . ' deployment to the status ' . $deploymentApplication->status)
                        ->actions([
                            Action::make('markAsUnread')
                                ->button()
                                ->markAsUnread(),
                            Action::make('markAsRead')
                                ->button()
                                ->markAsRead(),
                        ])
                        ->sendToDatabase(User::role('Admin')->get());           
            
                }),
                
                Tables\Actions\DeleteAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
}
