<?php

namespace App\Filament\Resources;

use App\Filament\Resources\InfectionPreventControlResource\Pages;
use App\Filament\Resources\InfectionPreventControlResource\RelationManagers;
use App\Models\InfectionPreventControl;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class InfectionPreventControlResource extends Resource
{
    protected static ?string $model = InfectionPreventControl::class;
    public static function getModelLabel(): string
    {
        return __('infectionPreventControl.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('in_healthcare_settings_id')
                ->label(__('infectionPreventControl.in_healthcare_settings'))
                    ->relationship('in_healthcare_settings', 'name')
                    ->required(),
                Forms\Components\Select::make('in_a_non_medical_id')
                ->label(__('infectionPreventControl.in_a_non_medical'))
                    ->relationship('in_a_non_medical', 'name')
                    ->required(),
                Forms\Components\Select::make('outbreak_investigations_id')
                ->label(__('infectionPreventControl.outbreak_investigations'))
                    ->relationship('outbreak_investigations', 'name')
                    ->required(),
                Forms\Components\Select::make('facility_assessments_id')
                ->label(__('infectionPreventControl.facility_assessments'))
                    ->relationship('facility_assessments', 'name')
                    ->required(),
                Forms\Components\Select::make('developing_infection_prevention_id')
                ->label(__('infectionPreventControl.developing_infection_prevention'))
                    ->relationship('developing_infection_prevention', 'name')
                    ->required(),
                Forms\Components\Select::make('infection_prevention_and_control_id')
                ->label(__('infectionPreventControl.infection_prevention_and_control'))
                    ->relationship('infection_prevention_and_control', 'name')
                    ->required(),
                Forms\Components\Select::make('quality_improvement_id')
                ->label(__('infectionPreventControl.quality_improvement'))
                    ->relationship('quality_improvement', 'name')
                    ->required(),
                Forms\Components\Select::make('ppe_id')
                ->label(__('infectionPreventControl.ppe'))
                    ->relationship('ppe', 'name')
                    ->required(),
                Forms\Components\Select::make('point_of_entry_border_health_id')
                ->label(__('infectionPreventControl.point_of_entry_border_health'))
                    ->relationship('point_of_entry_border_health', 'name')
                    ->required(),
                Forms\Components\Select::make('poc_non_border_id')
                ->label(__('infectionPreventControl.poc_non_border'))
                    ->relationship('poc_non_border', 'name')
                    ->required(),
                Forms\Components\Select::make('rsi_id')
                ->label(__('infectionPreventControl.rsi'))
                    ->relationship('rsi', 'name')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('in_healthcare_settings.name')
                ->label(__('infectionPreventControl.in_healthcare_settings'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('in_a_non_medical.name')
                ->label(__('infectionPreventControl.in_a_non_medical'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('outbreak_investigations.name')
                ->label(__('infectionPreventControl.outbreak_investigations'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('facility_assessments.name')
                ->label(__('infectionPreventControl.facility_assessments'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('developing_infection_prevention.name')
                ->label(__('infectionPreventControl.developing_infection_prevention'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('infection_prevention_and_control.name')
                ->label(__('infectionPreventControl.infection_prevention_and_control'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('quality_improvement.name')
                ->label(__('infectionPreventControl.quality_improvement'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('ppe.name')
                ->label(__('infectionPreventControl.ppe'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('point_of_entry_border_health.name')
                ->label(__('infectionPreventControl.point_of_entry_border_health'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('poc_non_border.name')
                ->label(__('infectionPreventControl.poc_non_border'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('rsi.name')
                ->label(__('infectionPreventControl.rsi'))
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('user.name')
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListInfectionPreventControls::route('/'),
            // 'create' => Pages\CreateInfectionPreventControl::route('/create'),
            // 'edit' => Pages\EditInfectionPreventControl::route('/{record}/edit'),
        ];
    }    
}
