<?php

namespace App\Filament\Resources;

use App\Filament\Resources\NutritionExperienceResource\Pages;
use App\Filament\Resources\NutritionExperienceResource\RelationManagers;
use App\Models\NutritionExperience;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class NutritionExperienceResource extends Resource
{
    protected static ?string $model = NutritionExperience::class;

    public static function getModelLabel(): string
    {
        return __('nutritionExperience.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationGroup = 'Trainings';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('assessment_nutritional_status_of_population_id')
                    ->label(__('nutritionExperience.assessment_of_the_nutritional_status_of_the_population'))
                    ->relationship('assessment_of_the_nutritional_status_of_the_population', 'name')
                    ->required(),
                // Forms\Components\TextInput::make('user_id')
                //     ->numeric(),
                Forms\Components\Select::make('certified')
                    ->label(__('nutritionExperience.certified'))
                   ->options([
                        'Yes' => 'Yes',
                        'No' => 'No',
                    ])
                ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('assessment_of_the_nutritional_status_of_the_population.name')
                    ->label(__('nutritionExperience.assessment_of_the_nutritional_status_of_the_population'))
                    ->numeric()
                    ->sortable(),
                Tables\Columns\TextColumn::make('certified')
                    ->label(__('nutritionExperience.certified'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('user.name')
                ->label(__('univ.user'))
                    ->numeric()
                    ->sortable(),
                    Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListNutritionExperiences::route('/'),
            // 'create' => Pages\CreateNutritionExperience::route('/create'),
            // 'edit' => Pages\EditNutritionExperience::route('/{record}/edit'),
        ];
    }    
}
