<?php

namespace App\Filament\Resources;

use App\Filament\Resources\QualificationResource\Pages;
use App\Filament\Resources\QualificationResource\RelationManagers;
use App\Models\Qualification;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

use Filament\Forms\Components\FileUpload;

class QualificationResource extends Resource
{
    protected static ?string $model = Qualification::class;

    public static function getModelLabel(): string
    {
        return __('qualification.title');
    }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                // Forms\Components\TextInput::make('user_id')
                //     ->numeric(),
                Forms\Components\TextInput::make('name')
                    ->label(__('qualification.name'))
                    ->required()
                    ->maxLength(255),
                Forms\Components\DatePicker::make('year_started')
                    ->label(__('qualification.year_started'))
                    ->required(),
                Forms\Components\DatePicker::make('year_completed')
                    ->label(__('qualification.year_completed'))
                    ->required(),
                Forms\Components\TextInput::make('institute')
                    ->label(__('qualification.institute'))
                    ->required()
                    ->maxLength(255),
                    FileUpload::make('upload_certificates')
                        ->label(__('qualification.upload_certificates'))
                        ->downloadable()
                        ->previewable(true)
                        ->multiple()
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                
                Tables\Columns\TextColumn::make('user.name')
                    ->label(__('univ.user'))
                    ->numeric()
                    ->sortable()->searchable(),
                Tables\Columns\TextColumn::make('name')
                    ->label(__('qualification.name'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('year_started')
                    ->label(__('qualification.year_started'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('year_completed')
                    ->label(__('qualification.year_completed'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('institute')
                    ->label(__('qualification.institute'))
                    ->searchable(),
                Tables\Columns\TextColumn::make('user.name')
                    ->sortable()
                    ->label(__('univ.user'))
                    ->visible(fn () => auth()->user()->hasAnyRole('Admin')),
                    Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true)
                    
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListQualifications::route('/'),
            // 'create' => Pages\CreateQualification::route('/create'),
            // 'edit' => Pages\EditQualification::route('/{record}/edit'),
        ];
    }    
}
