<?php

namespace App\Filament\Resources;

use App\Filament\Resources\RequestDatabaseResource\Pages;
use App\Filament\Resources\RequestDatabaseResource\RelationManagers;
use App\Models\RequestDatabase;
use App\Models\RequestType;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Tables\Columns\SelectColumn;
use Filament\Tables\Filters\Filter;
use Filament\Tables\Columns\IconColumn;
use Filament\Infolists\Components\TextEntry;

use Mohamedsabil83\FilamentFormsTinyeditor\Components\TinyEditor;

class RequestDatabaseResource extends Resource
{
    protected static ?string $model = RequestDatabase::class;

    public static function getModelLabel(): string
        {
            return __('requestDatabase.title');
        }

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\TextInput::make('request_name')
                    ->label(__('requestDatabase.requestName'))
                    ->maxLength(255)
                    ->columnSpan(2),
                Forms\Components\Select::make('requester_id')
                    ->label(__('requestDatabase.requestor'))
                    ->relationship('requester', 'name'),
                Forms\Components\Select::make('request_id')
                    ->label(__('requestDatabase.requestype'))
                    ->relationship('request', 'name')
                    //->options(RequestType::all()->pluck('name', 'id'))
                    ->multiple()
                    ->preload(),
                Forms\Components\Select::make('request_location_id')
                    ->label(__('requestDatabase.requestLocation'))
                    ->relationship('request_location', 'name'),
                Forms\Components\DatePicker::make('request_date')
                    ->label(__('requestDatabase.requestDate')),
                Forms\Components\Select::make('request_approval')
                    ->label(__('requestDatabase.requestApproval'))
                    ->options([
                        'Pending' => 'Pending',
                        'Approved' => 'Approved',
                        'Denied' => 'Denied'
                    ])
                    ->default('pending'),
                Forms\Components\DatePicker::make('date_of_request_approval_denial')
                    ->label(__('requestDatabase.requestNameApprovalDate')),
                TinyEditor::make('if_other_above_specify')
                    ->label(__('requestDatabase.ifOther'))
                    ->columnSpanFull(),
                Forms\Components\TextInput::make('request_duration')
                        ->label(__('requestDatabase.requestDitration'))
                        ->numeric(),
                Forms\Components\Select::make('duration_type')
                        ->label(__('requestDatabase.requestDurationtype'))
                        ->options([
                            'Days' => 'Days',
                            'Weeks' => 'Weeks',
                            'Months' => 'Months',
                            'Years' => 'Years',
                        ]),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('request_approval')
                ->label(__('requestDatabase.requestName'))
                    ->colors([
                        'primary',
                        'warning' => 'Pending',
                        'success' => 'Approved',
                        'danger' => 'Denied'
                    ])
                    ->searchable(),
                    // SelectColumn::make('request_approval')
                    // ->options([
                    //      'Pending' => 'Pending',
                    //     'Approved' => 'Approved',
                    //     'Denied' => 'Denied'
                    // ]),
                    // IconColumn::make('request_approval')
                    //  ->icon(fn (string $state): string => match ($state) {
                    //         'Pending' => 'heroicon-o-pencil',
                    //         'Approved' => 'heroicon-o-clock',
                    //         'Denied' => 'heroicon-o-check-circle',
                    //     })
                    // ->color(fn (string $state): string => match ($state) {
                    //     'Pending' => 'info',
                    //     'Approved' => 'warning',
                    //     'Denied' => 'success',
                    // }),
                Tables\Columns\TextColumn::make('request_name')
                ->label(__('requestDatabase.requestor'))
                    ->numeric()
                    ->sortable()
                    ->searchable(),
                Tables\Columns\TextColumn::make('requester.name')
                ->label(__('requestDatabase.requestype'))
                    ->numeric()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('request.name')
                ->label(__('requestDatabase.requestType'))
                    //->numeric()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('request_location.name')
                ->label(__('requestDatabase.requestLocation'))
                    ->numeric()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('request_date')
                ->label(__('requestDatabase.requestApproval'))
                    ->date()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('date_of_request_approval_denial')
                ->label(__('requestDatabase.requestNameApprovalDate'))
                    ->date()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('request_duration')
                ->label(__('requestDatabase.requestDitration'))
                    ->numeric()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('duration_type')
                ->label(__('requestDatabase.requestDurationtype'))
                
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.created_at')),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->searchable()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->label(__('univ.updated_at')),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->label(__('univ.deleted_at'))
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                Filter::make('is_approved')
                    ->query(fn (Builder $query): Builder => $query->where('request_approval', 'Approved'))
                    ->label('Approved'),
                Filter::make('is_denied')
                    ->query(fn (Builder $query): Builder => $query->where('request_approval', 'Denied'))
                    ->label('Denied'),
                Filter::make('is_pending')
                    ->query(fn (Builder $query): Builder => $query->where('request_approval', 'Pending'))
                    ->label('Pending')
            ])
            ->actions([
            
                // Tables\Actions\Action::make(name: 'Approve')
                //     ->action(function (RequestDatabase $record) {
                //     dump($record);
                //     }),
                Tables\Actions\EditAction::make(),
                Tables\Actions\ViewAction::make(),
                
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ])
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListRequestDatabases::route('/'),
            // 'create' => Pages\CreateRequestDatabase::route('/create'),
            // 'edit' => Pages\EditRequestDatabase::route('/{record}/edit'),
            // 'View' => Pages\ViewRequestDatabase::route('/{record}'),
        ];
    }    
}
