<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use App\Models\Traits\Multitenantable;

class DataManagement extends Model 
//implements HasMedia
{
    use SoftDeletes;
  //  use InteractsWithMedia;
    use HasFactory;
    use Multitenantable;

    public $table = 'data_managements';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'quantitative_data_id',
        'excel_id',
        'access_id',
        'sas_id',
        'spss_id',
        'status_id',
        'r_id',
        'epi_info_id',
        'monitoring_database_id',
        'qualitative_data_id',
        'data_visualization_id',
        'geographic_information_system_gis_id',
        'please_specify_other_software',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function quantitative_data()
    {
        return $this->belongsTo(TrainingLevel::class, 'quantitative_data_id');
    }

    public function excel()
    {
        return $this->belongsTo(TrainingLevel::class, 'excel_id');
    }

    public function access()
    {
        return $this->belongsTo(TrainingLevel::class, 'access_id');
    }

    public function sas()
    {
        return $this->belongsTo(TrainingLevel::class, 'sas_id');
    }

    public function spss()
    {
        return $this->belongsTo(TrainingLevel::class, 'spss_id');
    }

    public function status()
    {
        return $this->belongsTo(TrainingLevel::class, 'status_id');
    }

    public function r()
    {
        return $this->belongsTo(TrainingLevel::class, 'r_id');
    }

    public function epi_info()
    {
        return $this->belongsTo(TrainingLevel::class, 'epi_info_id');
    }

    public function monitoring_database()
    {
        return $this->belongsTo(TrainingLevel::class, 'monitoring_database_id');
    }

    public function qualitative_data()
    {
        return $this->belongsTo(TrainingLevel::class, 'qualitative_data_id');
    }

    public function data_visualization()
    {
        return $this->belongsTo(TrainingLevel::class, 'data_visualization_id');
    }

    public function geographic_information_system_gis()
    {
        return $this->belongsTo(TrainingLevel::class, 'geographic_information_system_gis_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
