<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\Traits\Multitenantable;

class LaboratoryExperience extends Model
{
    use SoftDeletes;
    use HasFactory;
    use Multitenantable;

    public $table = 'laboratory_experiences';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'user_id',
        'test_type_id',
        'biosafety_experience_id',
        'laboratory_quality_management_id',
        'sample_reception_and_acquisition_id',
        'sample_transport_id',
        'antimicrobial_id',
        'parasitology_id',
        'mycology_id',
        'clinical_chemistry_id',
        'blood_bank_id',
        'molecular_methods_id',
        'advanced_molecular_detection_dma_id',
        'viral_culture_id',
        'serology_id',
        'bsl_3_id',
        'bacterial_culture_id',
        'phlebotomy_venipuncture_id',
        'laboratory_training_instructor_id',
        'laboratory_supervisor_experience_id',
        'laboratory_field_intervention_coordinator_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $casts = [
        'test_type_id' => 'array',
    ];

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function biosafety_experience()
    {
        return $this->belongsTo(TrainingLevel::class, 'biosafety_experience_id');
    }
    public function test_type()
    {
        return $this->belongsToMany(TestType::class);
    }

    public function laboratory_quality_management()
    {
        return $this->belongsTo(TrainingLevel::class, 'laboratory_quality_management_id');
    }

    public function sample_reception_and_acquisition()
    {
        return $this->belongsTo(TrainingLevel::class, 'sample_reception_and_acquisition_id');
    }

    public function sample_transport()
    {
        return $this->belongsTo(TrainingLevel::class, 'sample_transport_id');
    }

    public function antimicrobial()
    {
        return $this->belongsTo(TrainingLevel::class, 'antimicrobial_id');
    }

    public function parasitology()
    {
        return $this->belongsTo(TrainingLevel::class, 'parasitology_id');
    }

    public function mycology()
    {
        return $this->belongsTo(TrainingLevel::class, 'mycology_id');
    }

    public function clinical_chemistry()
    {
        return $this->belongsTo(TrainingLevel::class, 'clinical_chemistry_id');
    }

    public function blood_bank()
    {
        return $this->belongsTo(AgencyRole::class, 'blood_bank_id');
    }

    public function molecular_methods()
    {
        return $this->belongsTo(TrainingLevel::class, 'molecular_methods_id');
    }

    public function advanced_molecular_detection_dma()
    {
        return $this->belongsTo(TrainingLevel::class, 'advanced_molecular_detection_dma_id');
    }

    public function viral_culture()
    {
        return $this->belongsTo(TrainingLevel::class, 'viral_culture_id');
    }

    public function serology()
    {
        return $this->belongsTo(TrainingLevel::class, 'serology_id');
    }

    public function bsl_3()
    {
        return $this->belongsTo(TrainingLevel::class, 'bsl_3_id');
    }

    public function bacterial_culture()
    {
        return $this->belongsTo(TrainingLevel::class, 'bacterial_culture_id');
    }

    public function phlebotomy_venipuncture()
    {
        return $this->belongsTo(TrainingLevel::class, 'phlebotomy_venipuncture_id');
    }

    public function laboratory_training_instructor()
    {
        return $this->belongsTo(TrainingLevel::class, 'laboratory_training_instructor_id');
    }

    public function laboratory_supervisor_experience()
    {
        return $this->belongsTo(TrainingLevel::class, 'laboratory_supervisor_experience_id');
    }

    public function laboratory_field_intervention_coordinator()
    {
        return $this->belongsTo(TrainingLevel::class, 'laboratory_field_intervention_coordinator_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
