<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use App\Models\Traits\Multitenantable;

class Register extends Model 
{
    use SoftDeletes;
    use HasFactory;
    use Multitenantable;

    public const FETP_MMBER_RADIO = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const FETP_GRADUATE_RADIO = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const EOC_EXPERIENCE_SELECT = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const PUBLIC_HEALTH_EXPERIENCE_DRC_RADIO = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const EXPERIENCE_AS_A_TEAM_LEADER_SELECT = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const INTERNATIONAL_WORK_EXPERIENCE_NO_STUDY_ABROAD_SELECT = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const NATIONAL_AGENCY_EMPLOYEE_SELECT = [
        'laboratory technician' => 'laboratory technician',
        'epidemiologist'        => 'epidemiologist',
        'logistician'           => 'logistician',
        'health communication'  => 'health communication',
        'Other'                 => 'Other',
    ];

    public $table = 'registers';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'agency_structure_id',
        'profession_id',
        'department_id',
        'name_of_supervisory_line_manager',
        'supervisorr_email',
        'fetp_mmber',
        'fetp_graduate',
        'country_residence_id',
        'city_of_residence',
        'workplace',
        'phone_number',
        'email_address',
        'national_agency_employee',
        'qualification_id',
        'other_qualifications',
        'public_health_experience_drc',
        'if_yes_number',
        'eoc_experience',
        'eoc_if_yes_number_of_years',
        'international_work_experience_no_study_abroad',
        'number_international_deployments',
        'experience_as_a_team_leader',
        'if_yes_above_number_of_deployments_as_tl',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
        'sex',
        'date_of_birth',
        'nationality_id',
        'national_id_number',
        'service_number',
    ];

    // public function registerMediaConversions(Media $media = null): void
    // {
    //     $this->addMediaConversion('thumb')->fit('crop', 50, 50);
    //     $this->addMediaConversion('preview')->fit('crop', 120, 120);
    // }

    public function agency_structure()
    {
        return $this->belongsTo(AgencyStructure::class, 'agency_structure_id');
    }
    public function department()
    {
        return $this->belongsTo(Department::class, 'department_id');
    }
    public function profession()
    {
        return $this->belongsTo(Profession::class, 'profession_id');
    }
    public function country_residence()
    {
        return $this->belongsTo(Country::class, 'country_residence_id');
    }
    public function nationality()
    {
        return $this->belongsTo(Country::class, 'nationality_id');
    }

    public function qualification()
    {
        return $this->belongsTo(Qualification::class, 'qualification_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
