<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Database\Eloquent\SoftDeletes;




class UserData extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
       public $table = 'users';
    protected $fillable = [
        'name',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    // protected function deployment_applicaton() 
    // {
    //     return $this->BelongsToMany(DeploymentApplication::class);
    // }
    
    public function deploymentOpportunities()
    {
        return $this->belongsToMany(DeploymentOpportunity::class, 'deployment_application');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
    public function register()
    {
        return $this->hasOne(Register::class, 'user_id');
    }
    
     public function case_management()
    {
        return $this->hasOne(CaseManagement::class, 'user_id');
    }
     public function data_management()
    {
        return $this->hasOne(DataManagement::class, 'user_id');
    }
     public function crec()
    {
        return $this->hasOne(Crec::class, 'user_id');
    }

     public function emergency_logistic()
    {
        return $this->hasOne(EmergencyLogistic::class, 'user_id');
    }

     public function emergency_response()
    {
        return $this->hasOne(EmergencyResponse::class, 'user_id');
    }

     public function experience_in_epidemiology()
    {
        return $this->hasOne(ExperienceInEpidemiology::class, 'user_id');
    }

     public function hazardous_materials_experience()
    {
        return $this->hasOne(HazardousMaterialsExperience::class, 'user_id');
    }

     public function infection_prevention_control()
    {
        return $this->hasOne(InfectionPreventControl::class, 'user_id');
    }

     public function laboratory_experience()
    {
        return $this->hasOne(LaboratoryExperience::class, 'user_id');
    }
   
     public function nutrition_experience()
    {
        return $this->hasOne(NutritionExperience::class, 'user_id');
    }
   
     public function psycosocial_experience()
    {
        return $this->hasOne(PsychosocialExperience::class, 'user_id');
    }
   
     public function security_manager_experience()
    {
        return $this->hasOne(SecurityManagerExperience::class, 'user_id');
    }
   
     public function water_sanitation_hygiene_wash()
    {
        return $this->hasOne(WaterSanitationHygieneWash::class, 'user_id');
    }
     public function readiness_and_rt_member()
    {
        return $this->hasOne(ReadinessAndRtMember::class, 'user_id');
    }


    public function admin_deployment_application()
    {
        return $this->belongsToMany(DeploymentOpportunity::class)
                     ->withPivot('status', 'user_response')
                    ->withTimestamps();
    }

      public function admin_user_deployment_application()
    {
        return $this->belongsToMany(DeploymentOpportunity::class)
                     ->withPivot('status', 'user_response')
                     ->withTimestamps();
    }

public function getUserResponseAttribute()
{
    return $this->admin_deployment_application->first()?->pivot?->user_response;
}


    //  protected static function booted(): void
    // {
    //     static::creating(function (User $user) {
    //         $user->role = 'user';
    //     });
    // }
}
